import { Motion } from "@capacitor/motion";
import { saveMotionInfo } from "../../save-motion-info";
import { useEffect } from "react";
/**
 * This hook subscribes to the acceleration event and saves the data to Deep
 *
 * @remarks
 * It is not recommended to use this hook directly. Instead of {@link WithUseAccelerationSubscription}
 */
export function useAccelerationSubscription(param) {
    const { deep, deviceLinkId } = param;
    useEffect(() => {
        const accelerationHandler = Motion.addListener('accel', async (accelData) => {
            await saveMotionInfo({
                deep,
                deviceLinkId,
                info: accelData,
            });
        });
        return () => {
            accelerationHandler.remove();
        };
    }, [deep, deviceLinkId]);
}
